import React, { MutableRefObject } from "react";
import { FileService, TreeHandler, TreeNode } from "./type";
export interface FileTreeProps {
    handlerRef?: MutableRefObject<TreeHandler | null>;
    /**
     * 无数据时展示
     */
    emptyRenderer?: () => React.ReactElement;
    /**
     * 渲染节点
     */
    treeItemRenderer?: (treeNode: TreeNode) => React.ReactNode;
    /**
     * 过滤特定节点，如果返回false，列表中不显示
     */
    doFilter?: (treeNode: TreeNode) => boolean;
    onTreeItemClick?: (treeNode: TreeNode) => void;
    rootUri?: string;
    /**
     * 构造菜单
     */
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>, treeNode: TreeNode) => void;
    fileService: FileService;
    /**
     * 根节点
     */
    root?: TreeNode;
    onError?: (err: Error) => void;
    onRootTreeChange?: (root: TreeNode | undefined) => void;
    /**
     * 子节点缩进尺寸
     */
    indent?: number;
    /**
     *  节点高度，默认30
     */
    rowHeight?: number;
    /**
     * 缩进单位，默认px
     */
    indentUnit?: string;
}
export declare const FileTree: React.ForwardRefExoticComponent<FileTreeProps & React.RefAttributes<{
    getRootNode: () => TreeNode | undefined;
    setRootNode: React.Dispatch<React.SetStateAction<TreeNode | undefined>>;
    getNode: (uri: string) => TreeNode | null | undefined;
    addNode: (uri: string, childNode: TreeNode) => void;
    replaceNode: (uri: string, replacedNode: TreeNode) => void;
    updateNode: (uri: string, record: Partial<TreeNode>) => void;
    removeNode: (uri: string) => void;
    expand: (uri: string, expanded: boolean) => Promise<void>;
    create: (uri: string, childNode: TreeNode) => Promise<void>;
    rename: (uri: string, name: string) => Promise<void>;
    remove: (uri: string) => Promise<void>;
    move: (uri: string, targetDirUri: string) => Promise<void>;
}>>;
